# resplendent
A reStructuredText plugin filter for pyspelling to check spelling errors in reStructuredText during CI checks.

# Additional Documentation:
* [News](NEWS.rst).
* [Code of Conduct](CODE_OF_CONDUCT.md).
* [Contribution Guidelines](CONTRIBUTING.md).
